<?php
/************************************************************************
 * Mailer v0.2.1-FINAL                                Start: 04/12/2004 *
 * ===================                          Last change: 11/16/2004 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : what-wernis.php                                  *
 * -------------------------------------------------------------------- *
 * Short description : Wernis requests                                  *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Auszahlungsanfragen                              *
 * -------------------------------------------------------------------- *
 * $Revision::                                                        $ *
 * $Date::                                                            $ *
 * $Tag:: 0.2.1-FINAL                                                 $ *
 * $Author::                                                          $ *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2009 by Roland Haeder                           *
 * Copyright (c) 2009 - 2013 by Mailer Developer Team                   *
 * For more information visit: http://mxchange.org                      *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Some security stuff...
if (!defined('__SECURITY')) {
	exit();
} elseif (!isMember()) {
	// User is not logged in
	redirectToIndexMemberOnlyModule();
}

// Add description as navigation point
addYouAreHereLink('member', __FILE__);

if ((!isExtensionActive('wernis')) && (!isAdmin())) {
	displayMessage('{%pipe,generateExtensionInactiveNotInstalledMessage=wernis%}');
	return;
} // END - if

// Check if the admin has entered the data
if ((getWernisApiId() == '') || (getWernisApiMd5() == '')) {
	// Something important is missing...
	displayMessage('{--MEMBER_WERNIS_API_DATA_MISSING--}');
	return;
} // END - if

// Init the content array and points
$content = array(); $points = FALSE;

// Is the mode set (withdraw or payout)
if ((!isGetRequestElementSet('do')) || (getRequestElement('do') == 'choose')) {
	// Let the user choose what he wants to do
	$content['wernis_userid'] = '0';

	// Is there an id?
	if ((!empty($content['wernis_userid'])) && (!isGetRequestElementSet('do'))) {
		// Then list all entries
		setGetRequestElement('do', 'list');

		// And load all rows!
		$result = sqlQueryEscaped("SELECT `id`, `wernis_account`, `wernis_amount`, `wernis_timestamp`, `wernis_type` FROM `{?_MYSQL_PREFIX?}_user_wernis` WHERE `userid`=%s ORDER BY `wernis_timestamp` DESC",
			array(getMemberId()), __FILE__, __LINE__);

		// Load all rows
		$content['rows'] = '';
		while ($data = sqlFetchArray($result)) {
			// Prepare data for output
			$rowContent = array(
				'wernis_timestamp' => generateDateTime($data['wernis_timestamp'], 2),
				'wernis_amount'    => $data['wernis_amount'],
				'wernis_account'   => $data['wernis_account'],
				'wernis_type'      => $data['wernis_type'],
			);

			// Load row template
			$content['rows'] .= loadTemplate('member_wernis_mode_list_row', TRUE, $rowContent);
		} // END - while

		// Free result
		sqlFreeResult($result);
	} else {
		// Default links are not active!
		$content['payout_link']   = '<span class="bad">{--MEMBER_WERNIS_PAYOUT_DISABLED--}</span>';
		$content['withdraw_link'] = '<span class="bad">{--MEMBER_WERNIS_WITHDRAW_DISABLED--}</span>';

		// Is the payout mode active?
		if (getConfig('wernis_payout_active') == 'Y') {
			// Add link
			$content['payout_link'] = '<a class="menu_blur" style="height: 40px" href="{%url=modules.php?module=login&amp;what=wernis&amp;do=payout%}"><div style="padding-top: 10px">{--MEMBER_WERNIS_MODE_PAYOUT--}</div></a>';
		} // END - if

		// Is the withdraw mode active?
		if (isWernisWithdrawActive()) {
			// Add link
			$content['withdraw_link'] = '<a class="menu_blur" style="height: 40px" href="{%url=modules.php?module=login&amp;what=wernis&amp;do=withdraw%}"><div style="padding-top: 10px">{--MEMBER_WERNIS_MODE_WITHDRAW--}</div></a>';
		} // END - if

		// Mode chooser! ;-)
		setGetRequestElement('do', 'choose');
	}
} elseif ((getRequestElement('do') == 'payout') && (getConfig('wernis_payout_active') == 'Y')) {
	// Get user's total points and remove the registration fee
	$points = getTotalPoints(getMemberId()) - getPointsRegister();

	// Is there a percentage or fixed fee?
	$points = WERNIS_TAKE_FEE($points, 'payout');

	// Is this enougth for a payout?
	if ($points < getConfig('wernis_min_payout')) {
		// No, then abort here
		displayMessage('{%message,MEMBER_WERNIS_MIN_PAYOUT=' . $points . '%}');
		return;
	} // END - if

	// No dots here...
	$points = explode('.', $points);
	$points = bigintval($points[0]);

	// Add points to content array
	$content['points']     = $points;
} elseif ((getRequestElement('do') == 'withdraw') && (isWernisWithdrawActive())) {
	// Prepare data for the template
	$content['points']        = getTotalPoints(getMemberId());
	$content['wernis_userid'] = '';

	// Fetch id
	$content['wernis_userid'] = getUserData('wernis_userid');
} else {
	// Invalid mode!
	displayMessage('{%message,MEMBER_WERNIS_MODE_INVALID=' . getRequestElement('do') . '%}');
	return;
}

// Is the formular sent?
if ((isFormSent()) && (isGetRequestElementSet('do'))) {
	// Is the user id and password set?
	if (!isPostRequestElementSet('wernis_userid')) {
		// Nothing entered in WDS66 user id
		displayMessage('{--MEMBER_WERNIS_EMPTY_USERNAME--}');
	} elseif (!isPostRequestElementSet('wds66_password')) {
		// Nothing entered in WDS66 password
		displayMessage('{--MEMBER_WERNIS_EMPTY_PASSWORD--}');
	} elseif (!isPostRequestElementSet('amount')) {
		// Nothing entered in amount
		displayMessage('{--MEMBER_WERNIS_EMPTY_AMOUNT--}');
	} elseif (postRequestElement('wernis_userid') != bigintval(postRequestElement('wernis_userid'))) {
		// Only numbers in account id!
		displayMessage('{--MEMBER_WERNIS_INVALID_USERNAME');
	} elseif (postRequestElement('amount') != bigintval(postRequestElement('amount'))) {
		// Only numbers in amount!
		displayMessage('{--MEMBER_WERNIS_INVALID_AMOUNT--}');
	} else {
		// Check input data depending on the mode and execute the requested mode
		switch (getRequestElement('do')) {
			case 'withdraw': // Widthdraws WDS66 -> This exchange
				if (postRequestElement('amount') < getConfig('wernis_min_withdraw')) {
					// Not enougth entered!
					displayMessage('{--MEMBER_WERNIS_WITHDRAW_AMOUNT_SMALLER_MIN--}');
				} else {
					// All is fine here so do the withdraw
					$success = WERNIS_EXECUTE_WITHDRAW(postRequestElement('wernis_userid'), hashSha256(postRequestElement('wds66_password')), postRequestElement('amount'));
					if ($success === TRUE) {
						// Add it to this amount
						initReferralSystem();
						addPointsThroughReferralSystem('wernis_withdraw', getMemberId(), bigintval(postRequestElement('amount')));

						// Update the user data as well..
						sqlQueryEscaped("UPDATE `{?_MYSQL_PREFIX?}_user_data` SET `wernis_userid`=%s WHERE `userid`=%s LIMIT 1",
							array(bigintval(postRequestElement('wernis_userid')), getMemberId()), __FILE__, __LINE__);

						// All done!
						displayMessage('{--MEMBER_WERNIS_WITHDRAW_DONE--}');
						return;
					} elseif ((GET_WERNIS_ERROR_CODE() == 'user_failed') || (GET_WERNIS_ERROR_CODE() == 'own_failed') || (GET_WERNIS_ERROR_CODE() == 'amount_failed')) {
						// Wrong login data
						displayMessage(GET_WERNIS_ERROR_MESSAGE());
					} else {
						// Something went wrong
						displayMessage('{--MEMBER_WERNIS_WITHDRAW_FAILED--}');
					}
				}
				break;

			case 'payout': // Payout this exchange -> WDS66
				if (postRequestElement('amount') < getConfig('wernis_min_payout')) {
					// Not enougth entered!
					displayMessage('{--MEMBER_WERNIS_PAYOUT_AMOUNT_SMALLER_MIN--}');
				} elseif (postRequestElement('amount') > $points) {
					// Not enougth points left!
					displayMessage(sprintf(getMessage('MEMBER_WERNIS_PAYOUT_POINTS_DEPLETED'), bigintval(postRequestElement('amount')), bigintval($points)));
				} else {
					// All is fine here so do the withdraw
					$success = WERNIS_EXECUTE_PAYOUT(postRequestElement('wernis_userid'), postRequestElement('amount'));
					if ($success === TRUE) {
						// Sub points and ignore return status
						subtractPoints('wernis_payout', getMemberId(), postRequestElement('amount'));

						// Update WDS66 id
						sqlQueryEscaped("UPDATE `{?_MYSQL_PREFIX?}_user_data` SET `wernis_userid`=%s WHERE `userid`=%s LIMIT 1",
							array(bigintval(postRequestElement('wernis_userid')), getMemberId()), __FILE__, __LINE__);

						// All done!
						displayMessage('{--MEMBER_WERNIS_PAYOUT_DONE--}');
						return;
					} elseif ((GET_WERNIS_ERROR_CODE() == 'user_failed') || (GET_WERNIS_ERROR_CODE() == 'own_failed') || (GET_WERNIS_ERROR_CODE() == 'amount_failed') || (GET_WERNIS_ERROR_CODE() == 'api_amount_failed')) {
						// Wrong login data
						displayMessage(GET_WERNIS_ERROR_MESSAGE());
					} else {
						// Something went wrong
						displayMessage('{--MEMBER_WERNIS_PAYOUT_FAILED--}');
					}
				}
				break;

			default: // Invalid mode!
				logDebugMessage(__FILE__, __LINE__, sprintf("Invalid mode %s detected.", getRequestElement('do')));
				displayMessage('{%message,MEMBER_WERNIS_MODE_INVALID=' . getRequestElement('do') . '%}');
				return;
		} // END - switch
	}
} // END - if

// Prepare mode for template name
$mode = sprintf("member_wernis_mode_%s", getRequestElement('do'));

// Load the template
loadTemplate($mode, FALSE, $content);

// [EOF]
?>
